run_setup

Function run_setup 

pub fn run_setup() -> Result<SerializableConfig, String>
Runs setup process

This runs the setup process for the Quorum server, prompting the user for necessary configurations and returning a SerializableConfig object.

Returns

A Result containing the SerializableConfig on success, or an error message as a String on failure.

Example

let config = run_setup().expect("Failed to run setup");