Function prompt_passphrase
Source pub fn prompt_passphrase() -> Result<String, String>
Prompts the user for a passphrase to encrypt/decrypt the server configuration.
Returns
A Result containing the entered passphrase as a String on success, or an error message as a String on failure.
Example
let passphrase = prompt_passphrase().expect("Failed to get passphrase");